#========================================================================================
# package      DE_EPAGES::Catalog::Hooks::Shop
# state        public
# description  create default shop
#========================================================================================
package DE_EPAGES::Catalog::Hooks::Shop;

use strict;
use DE_EPAGES::Object::API::Factory qw ( LoadClassByAlias );
use DE_EPAGES::Presentation::API::Template qw ( Translate );
use DE_EPAGES::Database::API::Connection     qw ( GetCurrentDBHandle );

#========================================================================================
# function     OnJSONAdvancedLinks
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnJSONAdvancedLinks( $hParams );
#----------------------------------------------------------------------------------------
# description  adds a link to to advanced links section in the link picker inside the
#               MBO
#               (Hook OBJ_JSONAdvancedLinks)
#----------------------------------------------------------------------------------------
# input        $hParams |
#               <ul>
#                   <li>Object - shop - object</li>
#                   <li>Values - attribute values - ref.hash</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnJSONAdvancedLinks {
    my ($hParams) = @_;
    my $Shop = $hParams->{'Object'};
    if($Shop->featureMaxValue('DetailedSearch')){
        my $SitePath = $hParams->{'Object'}->pathString;
        push @{$hParams->{'Links'}},{
            Alias=>Translate('DetailedSearch',undef,'DE_EPAGES::Catalog'),
            Link=>"?ViewAction=ViewDetailSearchProducts&ObjectPath=$SitePath"
        };
    }
}

#========================================================================================
# function     OnGetObjectsForXMLSitemap
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnGetObjectsForXMLSitemap( $hParams );
#----------------------------------------------------------------------------------------
# description  adds products to sitemap xml
#               (Hook API_GetObjectsForXMLSitemap)
#----------------------------------------------------------------------------------------
# input        $hParams |
#               <ul>
#                   <li>Object - shop - object</li>
#                   <li>ContentObjectHashs - array with object data - ref.array.hash</li>
#                   <li>MaxEntries - number of max entries allowed further - ref.integer</li>
#                   <li>CountLocales - number of locales in the shop - integer</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnGetObjectsForXMLSitemap {
    my ($hParams) = @_;
    my $Shop = $hParams->{'Object'};
    my $aContentObjectHashs = $hParams->{'ContentObjectHashs'};
    my $rMaxEntries = $hParams->{'MaxEntries'};
    my $CountLocales = $hParams->{'CountLocales'};

    # find visible products
    my $ProductClassID = LoadClassByAlias('Product')->id;

    #-- Retrieve all (master only) products objects that should be exported for the sitemap
    #-- Speed is important
    my $SqlParams = [
      $Shop->id,
    ];

    my $Sql = 'select productid from product p join contentobject co on p.productid = co.contentobjectid where co.siteid = ? and co.isvisible = 1 and p.superproductid is null';
    my $dbh = GetCurrentDBHandle();
    my $aaResults = $dbh->execute(
        $Sql,
        $SqlParams,
    );

    my @Products;
    push(@Products, $_->[0]) foreach @$aaResults;
    #--------------
    #-------------------------------------------

    if ($$rMaxEntries > 0){
        foreach my $ProductID ( @Products ) {
            last if $$rMaxEntries <= 0;
            push(@$aContentObjectHashs, {
                'ObjectID' => $ProductID,
                'ClassID' => $ProductClassID,
            });
            $$rMaxEntries -= $CountLocales; # each locale gets one entry in xml file
        }
    }
}

1;
