#==============================================================================
# package      DE_EPAGES::SEO::API::Constants
# state        public
#------------------------------------------------------------------------------
# description  Some constants used for export of sitmap.xml
#==============================================================================
package DE_EPAGES::SEO::API::Constants;
use base Exporter;

use strict;
use Readonly;

our @EXPORT_OK = qw(
    @BLACKLIST_MOBILECONTENT_CLASSES
    SEOCOCKPIT_NUM_UNTESTED
    SEOCOCKPIT_NUM_WORST
    SITEMAP_XML_URLS

    $SITEMAP_NAME
    $SITEMAP_NAME_MOBILE
    $SITEMAP_NAME_EXT
    $SITEMAP_EXPORT_FOLDER
);

use vars qw ( @BLACKLIST_MOBILECONTENT_CLASSES );

Readonly::Scalar our $SITEMAP_NAME => 'sitemap';                #-- name of sitemap index file
Readonly::Scalar our $SITEMAP_NAME_MOBILE => 'mobilesitemap';   #-- name of mobile sitemap index file
Readonly::Scalar our $SITEMAP_NAME_EXT => 'xml';                #-- extension of the sitemap index file
Readonly::Scalar our $SITEMAP_EXPORT_FOLDER => 'Sitemaps';      #-- folder name, where we store sub sitemap files

#========================================================================================
# global       @BLACKLIST_MOBILECONTENT_CLASSES | Classes that are not supported in the
#               mobile storefront yet and therefore should not be put into the mobile
#               sitemap xml file | ref.array.string
#========================================================================================
@BLACKLIST_MOBILECONTENT_CLASSES = qw(
    Forum
    GuestBook
    ImageGallery
    SiteMap
    BusinessHours
    Link
);

#========================================================================================
# global       $SEOCOCKPIT_NUM_UNTESTED | number of untested objects to display in SEO
#               cockpit (10) | int
# global       $SEOCOCKPIT_NUM_WORST | number of objects with worst SEO quality to
#               display in SEO cockpit (10) | int
#========================================================================================
use constant SEOCOCKPIT_NUM_UNTESTED => 10;
use constant SEOCOCKPIT_NUM_WORST => 10;

#========================================================================================
# global   SITEMAP_XML_URLS
#           | URLs for sitemap xml file submission
#           | ref.hash.string
# example  my $GoogleURL = SITEMAP_XML_URLS->{'Google'};
# example  foreach my $URL (values %{SITEMAP_XML_URLS()}) { ... }
#========================================================================================
use constant SITEMAP_XML_URLS => {
    'Google'    => 'http://www.google.com/webmasters/tools/ping?sitemap=',
    'Bing'      => 'http://www.bing.com/ping?sitemap=',
};

1;
