#========================================================================================
# package      DE_EPAGES::Zettle::API::WebService::DTO::BulkImageUploadItemDTO
# state        public
#----------------------------------------------------------------------------------------
# description  class to handle a single element from 'uploaded' field in bulk ImageUpload response
#               See Schemas > BulkImageUploadResponse in https://image.izettle.com/swagger
#========================================================================================
package DE_EPAGES::Zettle::API::WebService::DTO::BulkImageUploadItemDTO;

use strict;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::Zettle::API::WebService::DTO::BulkImageUploadItemDTO->new();
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Zettle::API::WebService::DTO::BulkImageUploadItemDTO
#========================================================================================
sub new {
    my $class = shift;
    my $self  = bless {}, $class;
    return $self;
}

# input        $ImageLookupKey | Image lookup key which matches image filename in Zettle (excluding extension) | string
sub imageLookupKey {
    my $self = shift;
    my ($ImageLookupKey) = @_;
    return $self->{'imageLookupKey'} unless defined($ImageLookupKey);
    $self->{'imageLookupKey'} = $ImageLookupKey;
}

# input        $aImageUrls | List of all image URLs generated in Zettle site associated to uploaded image.
#                             Original image is $aImageUrls[0] | ref.array.string
sub imageUrls {
    my $self = shift;
    my ($aImageUrls) = @_;
    return $self->{'imageUrls'} unless defined($aImageUrls);
    $self->{'imageUrls'} = $aImageUrls;
}

# input        $Source | Image URL source to link item back to bulk upload request | string
sub source {
    my $self = shift;
    my ($Source) = @_;
    return $self->{'source'} unless defined($Source);
    $self->{'source'} = $Source;
}

#========================================================================================
# function     fromHash
# state        public
#----------------------------------------------------------------------------------------
# syntax       $BulkImageUploadItemDTO = DE_EPAGES::Zettle::API::WebService::DTO::BulkImageUploadItemDTO->fromHash($hSingleBulkImageUploadResponse);
#----------------------------------------------------------------------------------------
# description  parse JSON contents from API ImageUpload response to produce a BulkImageUploadItemDTO object
#----------------------------------------------------------------------------------------
# input        $hSingleBulkImageUploadResponse | JSON structure retrieved from API image query.
#               See Schemas > BulkImageUploadResponse in https://image.izettle.com/swagger | string
#----------------------------------------------------------------------------------------
# return       $BulkImageUploadItemDTO | a image upload response object | DE_EPAGES::Zettle::API::WebService::DTO::BulkImageUploadItemDTO
#========================================================================================
sub fromHash {
    my $class = shift;

    my ($hSingleBulkImageUploadResponse) = @_;

    my $BulkImageUploadItemDTO = $class->new();
    $BulkImageUploadItemDTO->imageLookupKey($hSingleBulkImageUploadResponse->{'imageLookupKey'});
    $BulkImageUploadItemDTO->imageUrls($hSingleBulkImageUploadResponse->{'imageUrls'}) if defined $hSingleBulkImageUploadResponse->{'imageUrls'};
    $BulkImageUploadItemDTO->source($hSingleBulkImageUploadResponse->{'source'}) if defined $hSingleBulkImageUploadResponse->{'source'};

    return $BulkImageUploadItemDTO;
}

1;
