#========================================================================================
# package      DE_EPAGES::Zettle::API::WebService::DTO::BulkImageUploadResponseDTO
# state        public
#----------------------------------------------------------------------------------------
# description  class to handle bulk ImageUpload response
#               See Responses > Schema in https://image.izettle.com/swagger#/default/uploadProductImageBulk
#========================================================================================
package DE_EPAGES::Zettle::API::WebService::DTO::BulkImageUploadResponseDTO;

use strict;

use DE_EPAGES::Zettle::API::WebService::DTO::BulkImageUploadItemDTO;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::Zettle::API::WebService::DTO::BulkImageUploadResponseDTO->new();
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Zettle::API::WebService::DTO::BulkImageUploadResponseDTO
#========================================================================================
sub new {
    my $class = shift;
    my $self  = bless {}, $class;
    return $self;
}

# input        $aImageUploadResults | List of BulkImageUploadItemDTO objects.
#                                      See DE_EPAGES::Zettle::API::WebService::DTO::BulkImageUploadItemDTO | ref.array.object ## no critic qw(ProhibitLongLines)
sub imageUploadResults {
    my $self = shift;
    my ($aImageUploadResults) = @_;
    return $self->{'uploaded'} unless (defined($aImageUploadResults));
    $self->{'uploaded'} = $aImageUploadResults;
}

# input        $aInvalidUploads | List of invalid image uploads (images not processed for some reason) | ref.array.string ## no critic qw(ProhibitLongLines)
sub invalidUploads {
    my $self = shift;
    my ($aInvalidUploads) = @_;
    return $self->{'invalid'} unless (defined($aInvalidUploads));
    $self->{'invalid'} = $aInvalidUploads;
}

#========================================================================================
# function     fromHash
# state        public
#----------------------------------------------------------------------------------------
# syntax       $BulkImageUploadResponseDTO = DE_EPAGES::Zettle::API::WebService::DTO::BulkImageUploadResponseDTO->fromHash($hBulkImageUploadResponse); ## no critic qw(ProhibitLongLines)
#----------------------------------------------------------------------------------------
# description  parse JSON contents from API bulk ImageUpload response to produce a BulkImageUploadResponseDTO object. ## no critic qw(ProhibitLongLines)
#----------------------------------------------------------------------------------------
# input        $hBulkImageUploadResponse | JSON structure retrieved from API image query.
#                                           See Responses > Schema in https://image.izettle.com/swagger#/default/uploadProductImageBulk | string ## no critic qw(ProhibitLongLines)
#----------------------------------------------------------------------------------------
# return       $BulkImageUploadResponseDTO | a bulk image upload response object | DE_EPAGES::Zettle::API::WebService::DTO::BulkImageUploadResponseDTO ## no critic qw(ProhibitLongLines)
#========================================================================================
sub fromHash {
    my $class = shift;

    my ($hBulkImageUploadResponse) = @_;

    my $BulkImageUploadResponseDTO = $class->new();
    my @aImageUploadResults;
    foreach my $hSingleBulkImageUploadResponse (@{$hBulkImageUploadResponse->{'uploaded'}}){
        my $BulkImageUploadItemDTO = DE_EPAGES::Zettle::API::WebService::DTO::BulkImageUploadItemDTO->fromHash($hSingleBulkImageUploadResponse);
        push(@aImageUploadResults, $BulkImageUploadItemDTO);
    }
    $BulkImageUploadResponseDTO->imageUploadResults(\@aImageUploadResults);
    $BulkImageUploadResponseDTO->invalidUploads($hBulkImageUploadResponse->{'invalid'}) if defined $hBulkImageUploadResponse->{'invalid'};

    return $BulkImageUploadResponseDTO;
}

1;
