#========================================================================================
# package      DE_EPAGES::Zettle::API::WebService::DTO::LocationDTO
# state        public
#----------------------------------------------------------------------------------------
# description  class that wraps location information (note that for APIv3 the term is 'inventory')
#               See Responses in https://inventory.izettle.com/swagger#/default/getInventories
#               See Response example in https://developer.zettle.com/docs/api/inventory/user-guides/manage-inventories/fetch-inventories#fetch-all-inventories ## no critic qw(ProhibitLongLines)
#========================================================================================
package DE_EPAGES::Zettle::API::WebService::DTO::LocationDTO;

use strict;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::Zettle::API::WebService::DTO::LocationDTO->new();
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Zettle::API::WebService::DTO::LocationDTO
#========================================================================================
sub new {
    my $class = shift;
    my $self  = bless {}, $class;
    return $self;
}

#========================================================================================
# function     inventoryUuid
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Uuid = $self->inventoryUuid();
# syntax       $self->inventoryUuid($Uuid);
#----------------------------------------------------------------------------------------
# description  Get/Set location UUID.
#----------------------------------------------------------------------------------------
# input        $Uuid | Location UUIDv1 | string
#----------------------------------------------------------------------------------------
# return       $Uuid | Current location UUID if $Uuid parameter is not provided | string
#========================================================================================
sub inventoryUuid {
    my $self = shift;
    my ($Uuid) = @_;
    return $self->{'inventoryUuid'} unless defined($Uuid);
    $self->{'inventoryUuid'} = $Uuid;
}

#========================================================================================
# function     inventoryType
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Type = $self->inventoryType();
# syntax       $self->inventoryType($Type);
#----------------------------------------------------------------------------------------
# description  Get/Set location inventoryType.
#               Type can be any of: SUPPLIER, STORE, SOLD, BIN
#----------------------------------------------------------------------------------------
# input        $Type | Location inventoryType | string
#----------------------------------------------------------------------------------------
# return       $Type | Current location inventoryType if $Type parameter is not provided | string
#========================================================================================
sub inventoryType {
    my $self = shift;
    my ($Type) = @_;
    return $self->{'inventoryType'} unless defined($Type);
    $self->{'inventoryType'} = $Type;
}

#========================================================================================
# function     name
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Name = $self->name();
# syntax       $self->name($Name);
#----------------------------------------------------------------------------------------
# description  Get/Set location name.
#----------------------------------------------------------------------------------------
# input        $Name | Name of location | string
#----------------------------------------------------------------------------------------
# return       $Name | Current location name if $Name parameter is not provided | string
#========================================================================================
sub name {
    my $self = shift;
    my ($Name) = @_;
    return $self->{'name'} unless defined($Name);
    $self->{'name'} = $Name;
}

#========================================================================================
# function     description
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Description = $self->description();
# syntax       $self->description($Description);
#----------------------------------------------------------------------------------------
# description  Get/Set location description.
#----------------------------------------------------------------------------------------
# input        $Description | Location description | string
#----------------------------------------------------------------------------------------
# return       $Description | Current location description if $Description parameter is not provided | string
#========================================================================================
sub description {
    my $self = shift;
    my ($Description) = @_;
    return $self->{'description'} unless defined($Description);
    $self->{'description'} = $Description;
}

#========================================================================================
# function     defaultInventory
# state        public
#----------------------------------------------------------------------------------------
# syntax       $IsDefault = $self->defaultInventory();
# syntax       $self->defaultInventory($IsDefault);
#----------------------------------------------------------------------------------------
# description  Get/Set location default status.
#----------------------------------------------------------------------------------------
# input        $IsDefault | Location default status | boolean
#----------------------------------------------------------------------------------------
# return       $IsDefault | Current location default status if $IsDefault parameter is not provided.
#                            TRUE if location is the default one, false otherwise. | boolean
#========================================================================================
sub defaultInventory {
    my $self = shift;
    my ($IsDefault) = @_;
    return $self->{'defaultInventory'} unless defined($IsDefault);
    $self->{'defaultInventory'} = $IsDefault;
}

#========================================================================================
# function     fromHash
# state        public
#----------------------------------------------------------------------------------------
# syntax       $LocationDTO = DE_EPAGES::Zettle::API::WebService::DTO::LocationDTO->fromHash($hLocation);
#----------------------------------------------------------------------------------------
# description  Parse location info and return a LocationDTO object.
#               See Response example in https://developer.zettle.com/docs/api/inventory/user-guides/manage-inventories/fetch-inventories#fetch-all-inventories ## no critic qw(ProhibitLongLines)
#----------------------------------------------------------------------------------------
# input        $hLocation | Location data with following keys:
#               <ul>
#                   <li>inventoryUuid - location UUID - string
#                   <li>inventoryType - inventoryType of location, any of: SUPPLIER, STORE, SOLD, BIN - string
#                   <li>name - name of location - string
#                   <li>description - description of location - string
#                   <li>defaultInventory - location default status. TRUE if location is the default one - boolean
#               </ul> | ref.hash
#----------------------------------------------------------------------------------------
# return       $LocationDTO | a LocationDTO object | DE_EPAGES::Zettle::API::WebService::DTO::LocationDTO
#========================================================================================
sub fromHash {
    my $class = shift;
    my ($hLocation) = @_;

    my $LocationDTO = $class->new();
    $LocationDTO->inventoryUuid($hLocation->{'inventoryUuid'});
    $LocationDTO->inventoryType($hLocation->{'inventoryType'});
    $LocationDTO->name($hLocation->{'name'});
    $LocationDTO->description($hLocation->{'description'});
    $LocationDTO->defaultInventory($hLocation->{'defaultInventory'} eq 'true' ? 1 : 0);

    return $LocationDTO;
}

1;
