#========================================================================================
# package      DE_EPAGES::Zettle::API::WebService::DTO::ProductTrackingDTO
# state        public
#----------------------------------------------------------------------------------------
# description  class that wraps tracking information
#               See Responses > 200 > RESPONSE SCHEMA in https://developer.zettle.com/docs/api/inventory/reference#getTrackingStatusForProducts ## no critic qw(ProhibitLongLines)
#               See Response example in https://developer.zettle.com/docs/api/inventory/user-guides/manage-inventory-tracking/fetch-tracking-products-status#fetch-product-tracking-status ## no critic qw(ProhibitLongLines)
#========================================================================================
package DE_EPAGES::Zettle::API::WebService::DTO::ProductTrackingDTO;

use strict;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::Zettle::API::WebService::DTO::ProductTrackingDTO->new();
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::Zettle::API::WebService::DTO::ProductTrackingDTO
#========================================================================================
sub new {
    my $class = shift;
    my $self  = bless {}, $class;
    return $self;
}

#========================================================================================
# function     productUuid
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Uuid = $self->productUuid();
# syntax       $self->productUuid($Uuid);
#----------------------------------------------------------------------------------------
# description  Get/Set product UUID.
#----------------------------------------------------------------------------------------
# input        $Uuid | Product UUIDv1 | string
#----------------------------------------------------------------------------------------
# return       $Uuid | Current product UUID if $Uuid parameter is not provided | string
#========================================================================================
sub productUuid {
    my $self = shift;
    my ($Uuid) = @_;
    return $self->{'productUuid'} unless defined($Uuid);
    $self->{'productUuid'} = $Uuid;
}

#========================================================================================
# function     enabled
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Enabled = $self->enabled();
# syntax       $self->enabled($Enabled);
#----------------------------------------------------------------------------------------
# description  Get/Set tracking status.
#----------------------------------------------------------------------------------------
# input        $Enabled | Tracking status | boolean
#----------------------------------------------------------------------------------------
# return       $Enabled | Current tracking status if $Enabled parameter is not provided.
#                          TRUE if tracking is enabled, FALSE if disabled | boolean
#========================================================================================
sub enabled {
    my $self = shift;
    my ($Enabled) = @_;
    return $self->{'enabled'} unless defined($Enabled);
    $self->{'enabled'} = $Enabled;
}

#========================================================================================
# function     fromHash
# state        public
#----------------------------------------------------------------------------------------
# syntax       $ProductTrackingDTO = DE_EPAGES::Zettle::API::WebService::DTO::ProductTrackingDTO->fromHash($hProductTracking);
#----------------------------------------------------------------------------------------
# description  Parse tracking info and return a ProductTrackingDTO object.
#               See Response example in https://developer.zettle.com/docs/api/inventory/user-guides/manage-inventory-tracking/fetch-tracking-products-status#fetch-product-tracking-status ## no critic qw(ProhibitLongLines)
#----------------------------------------------------------------------------------------
# input        $hProductTracking | Location data with following keys:
#               <ul>
#                   <li>productUuid - location UUID - string
#                   <li>enabled - location default status - boolean
#               </ul> | ref.hash
#----------------------------------------------------------------------------------------
# return       $ProductTrackingDTO | a ProductTrackingDTO object | DE_EPAGES::Zettle::API::WebService::DTO::ProductTrackingDTO
#========================================================================================
sub fromHash {
    my $class = shift;
    my ($hProductTracking) = @_;

    my $ProductTrackingDTO = $class->new();
    $ProductTrackingDTO->productUuid($hProductTracking->{'productUuid'});
    $ProductTrackingDTO->enabled($hProductTracking->{'enabled'} eq 'true' ? 1 : 0);

    return $ProductTrackingDTO;
}

1;
